% This function computes the posterior median for the LNWS method. 
%
% Input
%  x -- observed wavelet coefficient
%  eps -- values of hyperparameter eps_j
%  b -- values of hyperparameter b
%
% Output
%  br -- posterior mean, shrunk version of observed wavelet coefficient
% -------------------------------------------------------------------------
function [br] = bayesrule_lnws_median(x,eps,b)

options=optimset('Display','off');

f0 = 1/(gamma(3/2)*2^(3/2))*x^(1/2)*exp(-x/2);
m = b/sqrt(1+2*b)*exp(-b*x/(1+2*b))* (2*normcdf(sqrt(x/(1+2*b)))-1);

if x==0 
    br=0; 
else if eps*f0/(eps*f0+(1-eps)*m)>0.5 
        br=0;
    else
        f2 = @(u) ( 1+(1-eps)/(eps*f0+(1-eps)*m)*b/sqrt(1+2*b)*exp(-b*x/(1+2*b))*( ...
            erf( ( (1+2*b)*sqrt(u)-sqrt(x))/sqrt(2+4*b) )- erf((sqrt(x)+(1+2*b)*sqrt(u))/sqrt(2+4*b)) ) )^1;
        br = lsqnonlin(f2,x,0,x,options);
    end;
end;


