% This function evaluates the marginal log-likelihood function for certain
% input values of the hyperparameters, therefore it is used to find
% estimates of the hyperparameters by empirical Bayes method.
%
% Input
%  par -- value of hyperparameters eps_j, j=J0,...,log2(N)-1 and b
%  d -- observed wavelet coefficients
%  coarsest -- coarsest level of wavelet decomposition (J0)
%
% Output
%  out -- value of the negative of the marginal log-likelihood
% -------------------------------------------------------------------------

function [out] = marg_lnws(par,d,coarsest)

out = 0;
n = length(par)-1;
for i = 1:n
dd = d(dyad(i+coarsest-1-1));
for j = 1:length(dd)
out = out + sum(log( par(i)*1/(gamma(3/2)*2^(3/2))*dd(j)^(1/2)*exp(-dd(j)/2)+...
    (1-par(i))*par(n+1)/sqrt(1+2*par(n+1))*exp(-par(n+1)*dd(j)/(1+2*par(n+1)))* (2*normcdf(sqrt(dd(j)/(1+2*par(n+1))))-1)  ));        
end;
end
out = -out;

